@@ -18,19 +18,31 @@ See hatta.py --help for usage.
 """
 
 # Exposed API
-from wiki import Wiki, WikiResponse, WikiRequest
-from config import WikiConfig, read_config
-from __main__ import main
-from parser import WikiParser, WikiWikiParser
-from storage import WikiStorage, WikiSubdirectoryStorage
-from page import WikiPage, WikiPageText, WikiPageWiki
-from page import WikiPageColorText, WikiPageFile, WikiPageImage
+from hatta.config import WikiConfig, read_config
+from hatta.__main__ import main
+from hatta.page import WikiPageColorText, WikiPageFile, WikiPageImage
+from hatta.page import WikiPage, WikiPageText, WikiPageWiki
+from hatta.parser import WikiParser, WikiWikiParser
+from hatta.storage import WikiStorage, WikiSubdirectoryStorage
+from hatta.wiki import Wiki, WikiResponse, WikiRequest
+from hatta.hg_integration import cmdtable
+
+
+__all__ = [
+    'WikiConfig', 'read_config',
+    'main',
+    'WikiPageColorText', 'WikiPageFile', 'WikiPageImage',
+    'WikiPage', 'WikiPageText', 'WikiPageWiki',
+    'WikiParser', 'WikiWikiParser',
+    'WikiStorage', 'WikiSubdirectoryStorage',
+    'Wiki', 'WikiResponse', 'WikiRequest',
+    '__version__', 'project_name', 'project_url', 'project_description',
+    'cmdtable',
+]
 
 # Project's metainformation
-__version__ = '1.5.0'
+__version__ = '1.5.1'
 project_name = 'Hatta'
 project_url = 'http://hatta-wiki.org/'
 project_description = 'Wiki engine that lives in Mercurial repository.'
 
-# Make it work as Mercurial extension
-from hg_integration import cmdtable
