@@ -1,10 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+import itertools
 import re
 import sys
 import unicodedata
-import itertools
 import werkzeug
 
 
@@ -100,7 +100,7 @@ class RuleSet(object):
             priority, pattern, function = self.rules[function_name]
             if bind_to is not None:
                 function = getattr(bind_to, function.__name__)
-            params = dict((k, v) for (k, v) in params.iteritems()
+            params = dict((str(k), v) for (k, v) in params.iteritems()
                           if v is not None and k not in self.rules)
             yield function(**params)
 
@@ -357,8 +357,9 @@ class WikiParser(object):
                 link_text, chunk = link_text.split('#', 1)
         match = self.image_re.match(link_text)
         if match:
-            params = match.groupdict()
-            image = self._line_image(*params)
+            params = dict((str(k), v) for (k, v) in
+                          match.groupdict().iteritems())
+            image = self._line_image(**params)
             return self.wiki_link(link_target, link_text, image=image)
         return self.wiki_link(link_target, link_text)
 
